#
# spec file for package iagno
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           iagno
Version:        3.38.1
Release:        bp156.3.7
Summary:        Reversi Game for GNOME
License:        GPL-3.0-or-later
Group:          Amusements/Games/Board/Other
URL:            https://wiki.gnome.org/Apps/Iagno
Source0:        https://download.gnome.org/sources/iagno/3.38/%{name}-%{version}.tar.xz
# PATCH-FIX-UPSTREAM b37eacaf1485cda54d0fa4b2d2423f3d8c620af1.patch dimstar@opensuse.org -- Fix build with Vala 0.51
Patch0:         https://gitlab.gnome.org/GNOME/iagno/-/commit/b37eacaf1485cda54d0fa4b2d2423f3d8c620af1.patch
BuildRequires:  fdupes
BuildRequires:  itstool
BuildRequires:  meson
BuildRequires:  pkgconfig
BuildRequires:  vala
BuildRequires:  pkgconfig(gio-2.0) >= 2.42.0
BuildRequires:  pkgconfig(glib-2.0) >= 2.42.0
BuildRequires:  pkgconfig(gsound) >= 1.0.2
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.24.0
BuildRequires:  pkgconfig(librsvg-2.0) >= 2.32.0

%description
Iagno is the two player strategy game of Othello, which is also known
as Reversi and is similar to Go. The pieces are tiles that are black
on one side and white on the other and the objective is for the player
to flip his/her opponent's tiles to his/her color, while keeping the
opponent from doing the same. Once the board is filled with tiles, the
winner is the player with the most of his/her color tiles on the
board.

%lang_package

%prep
%autosetup -p1

%build
%meson \
	%{nil}
%meson_build

%install
%meson_install
%find_lang %{name} %{?no_lang_C}
%fdupes %{buildroot}/%{_datadir}

%files
%license COPYING
%doc NEWS
%doc %{_datadir}/help/C/%{name}/
%{_bindir}/%{name}
%{_datadir}/%{name}/
%{_datadir}/metainfo/org.gnome.Reversi.appdata.xml
%{_datadir}/applications/org.gnome.Reversi.desktop
%{_datadir}/dbus-1/services/org.gnome.Reversi.service
%{_datadir}/glib-2.0/schemas/org.gnome.Reversi.gschema.xml
%{_datadir}/icons/hicolor/*/apps/*
%{_mandir}/man6/%{name}.6%{?ext_man}

%files lang -f %{name}.lang

%changelog
* Thu Feb 18 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Add b37eacaf1485cda54d0fa4b2d2423f3d8c620af1.patch: Fix build
  with vala 0.51.x.
* Thu Oct  8 2020 dimstar@opensuse.org
- Update to version 3.38.1:
  + Updated translations.
* Thu Oct  8 2020 dimstar@opensuse.org
- Update to version 3.38.0:
  + Updated translations.
* Thu Oct  8 2020 dimstar@opensuse.org
- Update to version 3.37.91:
  + A new app icon.
  + Updated translations.
- Drop iagno-add-missing-posix.patch: fixed upstream.
* Wed Oct  7 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.36.7:
  + Add missing posix,
  + Updated translations.
- Drop iagno-add-missing-posix.patch: Fixed upstream.
* Tue Aug  4 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Add iagno-add-missing-posix.patch: Fix build with new vala.
* Sat Jul  4 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.36.4:
  + Try to fix the symbolic icon.
  + Updated translations.
* Fri Jun  5 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.36.3:
  + Updated translations.
* Sat Apr 25 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.36.2:
  + Adapt to new HC theme.
  + Updated translations.
* Wed Mar 11 2020 mgorse@suse.com
- Update to version 3.36.0:
  + Updated translations.
* Tue Feb 18 2020 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 3.35.91:
  + The “Escape” key works again during a game.
  + The code that manages inputs (keyboard and mouse) changed
    a bit.
  + Help had cosmetic improvements.
  + Updated translations.
* Fri Feb 14 2020 dimstar@opensuse.org
- Update to version 3.35.90:
  + The History button is now drawn using the same images as the
    board; it removes the need to ensure a working font is
    installed. It also allowed to optimize a bit.
  + The "Vary start position" option now enables or disables the
    human opening when on a two-player game.
  + Transition to the game also changed on large windows.
  + Finally, help pages were reworked and are up-to-date.
- Changes from version 3.35.3:
  + There is now a new option (not checked by default) to highlight
    the playable tiles (yes, the playable ones, this time), for
    making the game easier for newcomers.
  + In the New Game screen, arrows have been added to the
    menubuttons for clarifying a bit what they are.
  + The window layout has improved on phone-like screens, with the
    game name being displayed in a bottom bar.
- Changes from version 3.35.2:
  + The most visible change is probably the first part of the
    replacement of the “Iagno” name by “Reversi”.
  + There is now a “--print-logs” command-line option for recording
    a game.
  + when configuring meson using option “-Dperfs_tests=true”, you
    can now check if the AI has been changed and test it for
    performance regressions.
  + Iagno should now be activatable using D-Bus.
- Changes from version 3.35.1:
  + Many changes! The biggest one is of course that Iagno now
    allows to play the reversed reversi game, that is played like
    an usual reversi game, but where the goal is to finish with
    less tiles than your opponent.
  + There is now a toggle to start with different initial
    positions randomly.
  + For two-player games, this is replaced by an old-style opening,
    where players place the four initial tiles on the board.
  + Another toggle to alternate who starts when a user is playing
    multiple times in a row.
  + Updated help.
  + Updated translations.
* Fri Feb 14 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.34.5:
  + Metadata fixes.
  + Updated translations.
* Sat Jan 25 2020 Dominique Leuenberger <dimstar@opensuse.org>
- No longer recommend -lang: supplements are in use
* Mon Jan  6 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.34.4:
  + Updated translations.
* Sat Nov 23 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.34.3:
  + Updated translations.
* Sat Oct 12 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.34.2:
  + Updated translations.
* Mon Oct  7 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.34.1:
  + Updated translations.
* Tue Sep 10 2019 mgorse@suse.com
- Update to version 3.34.0:
  + Updated translations.
* Wed Sep  4 2019 dimstar@opensuse.org
- Update to version 3.33.92:
  + Updated translations.
- Changes from version 3.33.91:
  + Some more AI things: had to adjust a bit their level, as they
    were too hard (!). Other than that, one small bug fixed.
- Changes from version 3.33.90:
  + The UI has changed a bit. The scorer is not displayed anymore,
    as it was suggesting the good strategy would be to turn as many
    pieces of the opponent as possible during a game (hint: it is
    not); it has been replaced by a simple indication of the
    current player, visible in the headerbar.
  + The New Game button was moved also, allowing to draw the board
    centered.
  + All this permits to make the game able to run on small screens,
    and it probably makes the window layout a bit cleaner.
  + For a similar reason, the themes dialog has gone and is now
    replaced by a submenu of the hamburger menu.
- Changes from version 3.33.5:
  + Just trying to fix build on some platforms.
- Changes from version 3.33.4:
  + Many changes; please, have fun testing.
  + First of all, there is a new AI (for Medium and Hard); it is
    only a depth 3 (for Hard) instead of a depth 6, and so there
    should never be a lag again; and it is a bit harder I think –at
    least, it defeats usually the old AI– while using mostly the
    same tricks, as its strategy feels a bit more obscure.
  + Secondly, if you play with a mouse, the currently targetted
    tile is highlighted, if it is playable; that feels not too much
    disturbing, but may be a bit reassuring sometimes.
  + Thirdly, an option has been added to highlight the opponent
    tiles that might be turned by a ply; that should be helpful for
    casual players and newbies. And, trying to play (using mouse
    or keyboard) on an occupied tile (briefly) highlights the
    playable tiles (this might evolve in the future).
- Changes from version 3.33.2:
  + The AI is now five times faster, for similar results.
- Replace pkgconfig(libcanberra) and pkgconfig(libcanberra-gtk3) by
  pkgconfig(gsound): follow upstreams port to GSound.
* Mon Mar 11 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.32.0:
  + Unfullscreen button added.
  + Added some keyboard shortcuts to improve the keyboard play when
    using some locales.
  + Updated translations.
* Thu Feb 21 2019 bjorn.lie@gmail.com
- Update to version 3.31.91:
  + The user can now display the final state of the game, by
    undoing after (or during) the final animation; and this
    animation is also more reliable (it was randomly failing).
    Also, the Adwaita (blue) theme that is used as default already
    if the user changes GNOME settings to always use dark theme is
    now also default when the Gtk theme is Adwaita-dark. Other than
    that, many code cleanings and various small fixes (highlight,
    focus).
  + Updated translations.
* Mon Feb 18 2019 bjorn.lie@gmail.com
- Update to version 3.31.90:
  + Iagno switched to Meson.
  + Use the org.gnome.Reversi application-id.
  + Updated translations.
- Switch to meson build system, add meson BuildRequires and macros.
- Add itstool and vala BuildRequires: New dependencies.
- Add explicit pkgconfig(gio-2.0) and pkgconfig(libcanberra)
  BuildRequires: align with what meson checks for.
- Drop obsolete hicolor-icon-theme and yelp-tools BuildRequires: No
  longer needed.
* Tue Jan  8 2019 bjorn.lie@gmail.com
- Update to version 3.31.4:
  + The application menu has been retired and replaced by an
    hamburger menu.
  + Updated translations.
* Fri Sep  7 2018 bjorn.lie@gmail.com
- Update to version 3.30.0:
  + Some Gitlab-migration-related.
  + Updated translations.
* Thu Mar 15 2018 luc14n0@linuxmail.org
- Update to version 3.28.0:
  + Updated translations.
- Update URL tag to https://wiki.gnome.org/Apps/Iagno: the current
  Iagno's web page.
- Drop:
  + intltool BuildRequires as upstream ported to Gettext.
  + update-desktop-files BuildRequires and suse_update_desktop_file
    macro: they are no longer required.
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Mon Oct  2 2017 luc14n0@linuxmail.org
- Update to version 3.26.1:
  + Some now-unused files removed.
  + Updated translations.
- Drop %%glib2_gsettings_schema_requires, %%glib2_gsettings_schema_*,
  %%desktop_database_* and %%icon_theme_cache_* post/postun macros:
  functionality now covered by file triggers.
* Tue Sep 20 2016 dimstar@opensuse.org
- Update to version 3.22.0:
  + Some AppData fixes.
  + Updated translations.
* Tue Sep 13 2016 zaitor@opensuse.org
- Update to version 3.21.92:
  + Updated translations.
* Tue Aug 30 2016 zaitor@opensuse.org
- Update to version 3.21.91:
  + Updated translations.
* Tue Aug 16 2016 dimstar@opensuse.org
- Update to version 3.21.90:
  + Update appdata.
  + Simplify style-checker enabling code.
  + Fix style-checker with new libgnome-games-support.
  + Add Language headers to po files.
  + Updated translations.
* Tue May 10 2016 zaitor@opensuse.org
- Update to version 3.20.2:
  + Updated translations.
* Thu Apr 14 2016 zaitor@opensuse.org
- Update to version 3.20.1:
  + Updated translations.
* Mon Mar 21 2016 dimstar@opensuse.org
- Update to version 3.20.0:
  + Updated translations.
* Tue Mar 15 2016 dimstar@opensuse.org
- Update to version 3.19.92:
  + The “valign” property of some buttons of the headerbar has been
    set to “center”, to look better on some rare configurations.
  + Updated translations.
* Tue Mar  1 2016 zaitor@opensuse.org
- Update to version 3.19.91:
  + Updated translations.
* Tue Feb 16 2016 zaitor@opensuse.org
- Update to version 3.19.90:
  + The “Black and White” (high_contrast) theme has evolved to look
    good when used with the new GTK+ theme “HighContrastInverse”,
    and is set as the default for it.
  + Updates of the metadata files (AppData and Doap).
  + Add a code style checker.
  + Updated translations.
* Tue Nov 24 2015 zaitor@opensuse.org
- Update to version 3.19.1:
  + Adaptation to current CSS-nodes (will break again).
  + Updated translations.
* Thu Nov 12 2015 zaitor@opensuse.org
- Update to version 3.18.2:
  + Update CSS for uses with newer Gtk+.
  + Updated translations.
* Mon Oct 12 2015 zaitor@opensuse.org
- Update to version 3.18.1:
  + Better error message.
  + Updated translations.
* Mon Sep 21 2015 dimstar@opensuse.org
- Update to version 3.18.0:
  + Updated translations.
* Wed Sep 16 2015 dimstar@opensuse.org
- Update to version 3.17.92:
  + Fix dragging the window after clicking the game view.
* Wed Sep  2 2015 zaitor@opensuse.org
- Update to version 3.17.91:
  + Updated translations.
* Tue Aug 18 2015 zaitor@opensuse.org
- Update to version 3.17.90:
  + Add support for rounded-squared tiles in themes.
  + Update screenshots in help.
  + Print --version output on stdout.
  + Updated translations.
* Tue Apr 28 2015 zaitor@opensuse.org
- Update to version 3.17.1:
  + Add keyboard support.
  + Update drawing function.
* Wed Apr 15 2015 dimstar@opensuse.org
- Update to version 3.16.1:
  + Temporarily remove Sun and Star theme, that causes a memory
    leak.
  + HighContrast icons removed (as the symbolic one is now used).
  + Updated translations.
* Mon Mar 23 2015 dimstar@opensuse.org
- Update to version 3.16.0:
  + Updated translations.
* Tue Mar 17 2015 dimstar@opensuse.org
- Update to version 3.15.92:
  + Add symbolic icon.
  + Don't crash when closing.
  + Restore the hack that makes the new-game screen work correctly.
  + Better code for command-line options.
  + Introduce one (two) CSS hack(s) for a weird HighContrast
    (non-)behaviour.
  + Updated translations.
* Tue Mar  3 2015 dimstar@opensuse.org
- Update to version 3.15.91:
  + Big code reorganisation, correcting some weird bugs,
    including a crasher.
  + Updated translations.
* Tue Feb 17 2015 dimstar@opensuse.org
- Update to version 3.15.90.2:
  + Real fix that makes themes work.
* Tue Feb 17 2015 dimstar@opensuse.org
- Update to version 3.15.90.1:
  + Fix distcheck.
- Changes from version 3.15.90:
  + Scoreboard that changes with the theme.
  + New themes' dialog, new themes.
  + Implement new design for new game screen.
  + Switch from appdata-tools to appstream-utils.
  + Updated translations.
- Change license to GPL-3.0, following upstreams relicensing.
* Tue Nov 18 2014 zaitor@opensuse.org
- Update to version 3.15.1:
  + Make the background green and thicken the grid.
  + Use piece images instead of text in the scoreboard.
  + Add a new game screen.
  + The AI is now much weaker on level one.
  + The AI no longer blocks the UI thread to think.
  + The AI takes more time to move when only one spot remains.
  + Move sound preference to the app menu.
  + Add ability to change board size with command line.
  + Add alternative starting position command line switch.
  + Accept right clicks as input, since why not?
  + Code cleanups.
  + Very many internal changes.
  + Updated translations.
* Wed Nov 12 2014 zaitor@opensuse.org
- Update to version 3.14.2:
  + Updated translations.
* Fri Oct 10 2014 dimstar@opensuse.org
- Update to version 3.14.1:
  + The level one AI is now much easier.
  + Updated translations.
* Mon Sep 22 2014 dimstar@opensuse.org
- Update to version 3.14.0:
  + Updated appdata.
  + Updated translations.
* Mon Sep  1 2014 zaitor@opensuse.org
- Update to version 3.13.91:
  + AI fixes and improvements, hopefully.
  + Never create multiple preferences dialogs.
  + Restore <ctrl>Z shortcut for undo move.
  + Updated translations.
* Mon Aug 18 2014 dimstar@opensuse.org
- Update to version 3.13.90:
  + Distribute HighContrast icons.
  + Disallow undo if only computer has moved.
  + Use an AspectFrame to ensure all looks good.
  + Update man page.
  + Updated translations.
- Build HighContrast icon cache in post/postun.
* Mon Jul 21 2014 dimstar@opensuse.org
- Update to version 3.13.4:
  + Use a text label for the new game button.
  + Use header bar on preferences dialog.
  + Use better window title for preferences dialog.
  + Preferences dialog changes.
  + Do not allow computer vs. computer games.
  + Add some new command line options.
  + Add a jumplist to the desktop file.
  + Window layout tweaks.
  + Updated translations.
* Sat May 17 2014 zaitor@opensuse.org
- Update to version 3.12.2:
  + Updated translations.
* Mon Apr 14 2014 zaitor@opensuse.org
- Update to version 3.12.1:
  + Updated translations.
* Mon Mar 24 2014 zaitor@opensuse.org
- Update to version 3.12.0:
  + Fix some bugs with the user help.
  + Updated translations.
* Mon Mar 17 2014 dimstar@opensuse.org
- Update to version 3.11.92:
  + Fix padding around scoreboard.
  + Attempt to center the board using wide window sizes.
  + Updated translations.
* Mon Feb 17 2014 zaitor@opensuse.org
- Update to version 3.11.90:
  + Now uses a header bar.
  + Removed the info bar. Messages are now displayed in the header
    bar instead.
  + Undo Move has moved from the app menu to the header bar.
  + The grid is now solid and mandatory, and sits on the left side
    of the window.
  + A new game button now appears in the window after the game is
    complete.
  + Flip final result preference removed; this is now mandatory.
  + The computer now moves more slowly, to avoid overwhelming the
    player.
  + Iagno can be started with -f or --fast-mode to avoid this
    delay.
  + Many older themes have been removed.
  + Updated man page
  + Updated translations.
* Tue Nov 19 2013 dimstar@opensuse.org
- Update to version 3.11.2:
  + Updated translations.
* Wed Oct 30 2013 dimstar@opensuse.org
- Update to version 3.11.1:
  + Make the AI play much slower to give the game a more natural
    tempo.
  + Fix serious bug affecting the performance of the AI.
  + Miscellaneous code cleanups.
  + Add some simple test cases.
  + Appdata is now translatable.
  + Updated translations.
* Sun Oct 13 2013 dimstar@opensuse.org
- Update to version 3.10.1:
  + Fix crazy computers when starting a new game in computer vs.
    computer mode.
  + Fix bug affecting the correctness of the computer's choice of
    moves.
  + Fix additional low-level issues triggered by computer search,
    including one that caused the piece flip sound to play many
    times in close succession.
  + Fix undo after having passed.
  + Fix infobar disappearing if intended to be displayed two moves
    in a row.
  + Fix piece flipped sound improperly playing at the start of the
    game.
  + Reallow undo after the game has ended.
  + Add delay between last move and final flip to prevent the
    scenario where it appears the last player placed a piece of the
    wrong color.
  + Updated translations.
* Mon Sep 23 2013 dimstar@opensuse.org
- Update to version 3.10.0:
  + Stable release, no changes.
* Tue Sep 17 2013 dimstar@opensuse.org
- Update to version 3.9.92:
  + Show the grid by default so the edges of the board are clear.
  + Fix hang after many pieces have been placed on the board.
  + Fix hang when neither player has a valid move.
  + Prohibit Undo after the game has ended.
* Tue Sep  3 2013 dimstar@opensuse.org
- Update to version 3.9.91:
  + Add an AppData file.
* Sat Aug 24 2013 zaitor@opensuse.org
- Add fdupes buildrequires, and use fdupes macro to get rid of
  duplicate help files.
* Wed Aug 21 2013 dimstar@opensuse.org
- Update to version 3.9.90:
  + Alphabetize theme selection in Preferences.
  + Display the correct score at the end of the game.
  + Fix two broken links in user help.
  + Updated translations.
* Mon Apr 15 2013 dimstar@opensuse.org
- Update to version 3.8.1:
  + Updated translations.
* Wed Mar 27 2013 dimstar@opensuse.org
- Update to version 3.8.0:
  + Merge themes from extras module.
  + Updated translations.
* Tue Mar  5 2013 dimstar@opensuse.org
- Initial package, version 3.7.90: split-off from gnome-games.
